adagrad(inputData, outputData, list)rowLength: a integer of data length (row).
theta: a matrix of float number of current model value.
alpha : a float value for learning rate.
momentum : a float value to give a constant speed to learning process..
smooth : a float value to handle zero division issue in certain learning method.
stochastic : a boolean value to enable stochastic, which mean to select one random
value in data train, instead process all data train.
accelerate : a boolean value to enable accelerate in the learning with momentum.
maxIter : Adaptive Moment Estimation method to calculate gradient.